@@ -371,12 +371,37 @@ export async function evaluateExpressionAsync(expr, options = null, locals = nul
             if (typeof leftValue === 'number' && typeof rightValue === 'number') {
                 return leftValue % rightValue;
             }
-        } else {
-            // binOp === '**'
+        } else if (binOp === '**') {
             // number ** number
             if (typeof leftValue === 'number' && typeof rightValue === 'number') {
                 return leftValue ** rightValue;
             }
+        } else if (binOp === '&') {
+            if (typeof leftValue === 'number' && Math.floor(leftValue) === leftValue &&
+                typeof rightValue === 'number' && Math.floor(rightValue) === rightValue) {
+                return leftValue & rightValue;
+            }
+        } else if (binOp === '|') {
+            if (typeof leftValue === 'number' && Math.floor(leftValue) === leftValue &&
+                typeof rightValue === 'number' && Math.floor(rightValue) === rightValue) {
+                return leftValue | rightValue;
+            }
+        } else if (binOp === '^') {
+            if (typeof leftValue === 'number' && Math.floor(leftValue) === leftValue &&
+                typeof rightValue === 'number' && Math.floor(rightValue) === rightValue) {
+                return leftValue ^ rightValue;
+            }
+        } else if (binOp === '<<') {
+            if (typeof leftValue === 'number' && Math.floor(leftValue) === leftValue &&
+                typeof rightValue === 'number' && Math.floor(rightValue) === rightValue) {
+                return leftValue << rightValue;
+            }
+        } else {
+            // if (binOp === '>>')
+            if (typeof leftValue === 'number' && Math.floor(leftValue) === leftValue &&
+                typeof rightValue === 'number' && Math.floor(rightValue) === rightValue) {
+                return leftValue >> rightValue;
+            }
         }
 
         // Invalid operation values
@@ -389,8 +414,15 @@ export async function evaluateExpressionAsync(expr, options = null, locals = nul
         const value = await evaluateExpressionAsync(expr.unary.expr, options, locals, builtins);
         if (unaryOp === '!') {
             return !valueBoolean(value);
-        } else if (unaryOp === '-' && typeof value === 'number') {
-            return -value;
+        } else if (unaryOp === '-') {
+            if (typeof value === 'number') {
+                return -value;
+            }
+        } else {
+            // if (unaryOp === '~'
+            if (typeof value === 'number' && Math.floor(value) === value) {
+                return ~value;
+            }
         }
 
         // Invalid operation value
